==> airbridge_flutter_sdk-1.1.0.tar.gz: ios/Classes/AFLConfigReader.m <==
//
//  AFLConfigReader.m
//  AirbridgeFL
//
//  Created by WOF on 2020/06/22.
//  Copyright © 2020 ab180. All rights reserved.
//

#import "AFLConfigReader.h"

#import "AFLGet.h"

#import <AirBridge/AirBridge.h>
#import <Flutter/FlutterDartProject.h>

@implementation AFLConfigReader

+ (void) apply {
    NSString* key = [FlutterDartProject lookupKeyForAsset:@"assets/airbridge.json"];
    NSString* path = [[NSBundle mainBundle] pathForResource:key ofType:nil];
    NSData* data = [NSData dataWithContentsOfFile:path];
    NSDictionary* json = [NSJSONSerialization JSONObjectWithData:data options:0 error:nil];
    
    NSNumber* sessionTimeoutSeconds = [AFLGet type:NSNumber.class dictionary:json key:@"sessionTimeoutSeconds"];
    if (sessionTimeoutSeconds != nil) {
        [AirBridge setSessionTimeout:sessionTimeoutSeconds.intValue * 1000];
    }
    
    NSNumber* autoStartTrackingEnabled = [AFLGet type:NSNumber.class dictionary:json key:@"autoStartTrackingEnabled"];
    if (autoStartTrackingEnabled != nil) {
        [AirBridge setIsLimitTracking:!autoStartTrackingEnabled.boolValue];
    }
    
    NSNumber* userInfoHashEnabled = [AFLGet type:NSNumber.class dictionary:json key:@"userInfoHashEnabled"];
    if (userInfoHashEnabled != nil) {
        [AirBridge setIsUserInfoHashed:userInfoHashEnabled.boolValue];
    }
    
    NSNumber* trackAirbridgeLinkOnly = [AFLGet type:NSNumber.class dictionary:json key:@"trackAirbridgeLinkOnly"];
    if (trackAirbridgeLinkOnly != nil) {
        [AirBridge setIsTrackAirbridgeDeeplinkOnly:trackAirbridgeLinkOnly.boolValue];
    }
    
    NSNumber* facebookDeferredAppLinkEnabled = [AFLGet type:NSNumber.class dictionary:json key:@"facebookDeferredAppLinkEnabled"];
    if (facebookDeferredAppLinkEnabled != nil) {
        [AirBridge setIsFacebookDeferredAppLinkEnabled:facebookDeferredAppLinkEnabled.boolValue];
    }
    
    [AirBridge.state setSDKDevelopmentPlatform:@"flutter"];
}

@end

==> airbridge_flutter_sdk-1.1.1.tar.gz: ios/Classes/AFLConfigReader.m <==
//
//  AFLConfigReader.m
//  AirbridgeFL
//
//  Created by WOF on 2020/06/22.
//  Copyright © 2020 ab180. All rights reserved.
//

#import "AFLConfigReader.h"

#import "AFLGet.h"

#import <AirBridge/AirBridge.h>
#import <Flutter/FlutterDartProject.h>

@implementation AFLConfigReader

+ (void) apply {
    NSString* key = [FlutterDartProject lookupKeyForAsset:@"assets/airbridge.json"];
    NSString* path = [[NSBundle mainBundle] pathForResource:key ofType:nil];
    NSData* data = [NSData dataWithContentsOfFile:path];
    NSDictionary* json = nil;
    if (data != nil) {
        json = [NSJSONSerialization JSONObjectWithData:data options:0 error:nil];
    }
    
    NSNumber* sessionTimeoutSeconds = [AFLGet type:NSNumber.class dictionary:json key:@"sessionTimeoutSeconds"];
    if (sessionTimeoutSeconds != nil) {
        [AirBridge setSessionTimeout:sessionTimeoutSeconds.intValue * 1000];
    }
    
    NSNumber* autoStartTrackingEnabled = [AFLGet type:NSNumber.class dictionary:json key:@"autoStartTrackingEnabled"];
    if (autoStartTrackingEnabled != nil) {
        [AirBridge setAutoStartTrackingEnabled:autoStartTrackingEnabled.boolValue];
    }
    
    NSNumber* userInfoHashEnabled = [AFLGet type:NSNumber.class dictionary:json key:@"userInfoHashEnabled"];
    if (userInfoHashEnabled != nil) {
        [AirBridge setIsUserInfoHashed:userInfoHashEnabled.boolValue];
    }
    
    NSNumber* trackAirbridgeLinkOnly = [AFLGet type:NSNumber.class dictionary:json key:@"trackAirbridgeLinkOnly"];
    if (trackAirbridgeLinkOnly != nil) {
        [AirBridge setIsTrackAirbridgeDeeplinkOnly:trackAirbridgeLinkOnly.boolValue];
    }
    
    NSNumber* facebookDeferredAppLinkEnabled = [AFLGet type:NSNumber.class dictionary:json key:@"facebookDeferredAppLinkEnabled"];
    if (facebookDeferredAppLinkEnabled != nil) {
        [AirBridge setIsFacebookDeferredAppLinkEnabled:facebookDeferredAppLinkEnabled.boolValue];
    }
    
    [AirBridge.state setSDKDevelopmentPlatform:@"flutter"];
}

@end
